@@ -164,3 +164,54 @@ clearConsole <- function(){
         system('clear')
     }
 }
+
+
+#### Plotting functions ####
+
+# Define universal plot settings
+#
+# @param    sizing  defines the style and sizing of the theme. One of 
+#                   \code{c("figure", "window")} where \code{sizing="figure"} is appropriately
+#                   sized for pdf export at 7 to 7.5 inch width, and \code{sizing="window"}
+#                   is sized for an interactive session.
+#
+# @return   A ggplot2 theme object.
+getBaseTheme <- function(sizing=c("figure", "window")) {
+    # Check arguments
+    sizing <- match.arg(sizing)
+    
+    # Define universal plot settings appropriate for PDF figures
+    if (sizing == "figure") {
+        base_theme <- theme_bw() + 
+            theme(text=element_text(size=8)) +
+            theme(plot.title=element_text(size=8)) +
+            theme(plot.background=element_blank(),
+                  panel.grid.major=element_blank(), 
+                  panel.grid.minor=element_blank()) +
+            theme(strip.background=element_blank(),
+                  strip.text=element_text(size=7, face='bold')) +
+            theme(axis.title=element_text(size=8, vjust=0.25),
+                  axis.text.x=element_text(size=8, vjust=0.5, hjust=0.5),
+                  axis.text.y=element_text(size=8)) +
+            theme(legend.text=element_text(size=7),
+                  legend.title=element_text(size=7),
+                  legend.key.height=grid::unit(10, "points"), 
+                  legend.key.width=grid::unit(10, "points"))
+    } else if (sizing == "window") {
+        # Define universal plot settings appropriate for an interactive session
+        base_theme <- theme_bw() + 
+            theme(text=element_text(size=14)) +
+            theme(plot.title=element_text(size=16)) +
+            theme(strip.background=element_rect(fill='white'), 
+                  strip.text=element_text(size=14, face='bold')) +
+            theme(axis.title=element_text(size=16, vjust=0.25),
+                  axis.text.x=element_text(size=16, vjust=0.5, hjust=0.5),
+                  axis.text.y=element_text(size=16)) +
+            theme(legend.text=element_text(size=14),
+                  legend.title=element_text(size=14),
+                  legend.key.height=grid::unit(18, "points"), 
+                  legend.key.width=grid::unit(18, "points"))
+    }
+    
+    return(base_theme)
+}
